/* $Id: MUSICDescriptor.cc,v 1.3 2003/09/19 12:26:47 andete Exp $

lemux - LADSPA instrument plugins based on openMSX devices

(c) 2003 Joost Yervante Damad <joost@lumatec.be>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "MUSICDescriptor.hh"
#include "LADSPAPluginInstance.hh"
#include "LADSPAPortDescriptor.hh"
#include "LADSPAPluginDescriptor.hh"
#include "MUSICInstance.hh"

#include <string>
#include <sstream>

MUSICDescriptor::MUSICDescriptor()
:
	LADSPAPluginDescriptor
		(
			2064,
			std::string("MUSIC"),
			std::string("MUSIC channel"),
			std::string("Joost Yervante Damad"),
			std::string("GPLv2")
		)
{
	LADSPAPortDescriptor *port;

	port = new LADSPAPortDescriptor
		(
			std::string("Freq (Hz)"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::SampleRate   |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default440,

			0,
			0.5
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Amplitude"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Integer |
				LADSPAPortDescriptor::Default0,

			0,
			15
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Preset"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::Integer |
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Sustain"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier AM"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Vibrato"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Percussive"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Rate Key Scale"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Wave Multiply"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0, 15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Key Scale Level"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,3
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Distortion Waveform"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		);
	addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Env A"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Env D"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Env S"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Carrier Env R"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator AM"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Vibrato"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Percussive"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Rate Key Scale"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Wave Multiply"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0, 15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Key Scale Level"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,3
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Modulator Total Level"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::Integer |
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			63
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Distortion Waveform"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Toggled ,

			0
		);
	addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator FM feedback"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,7
		); addPort(port);
	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Env A"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Env D"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Env S"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);

	port = new LADSPAPortDescriptor
	(
		std::string("Modulator Env R"),
	
			LADSPAPortDescriptor::Input   |
			LADSPAPortDescriptor::Control ,
		
			LADSPAPortDescriptor::Default0|
			LADSPAPortDescriptor::Integer |
			LADSPAPortDescriptor::BoundedBelow |
			LADSPAPortDescriptor::BoundedAbove,

			0,15
		); addPort(port);
	port = new LADSPAPortDescriptor
		(
			std::string("Output"),
			
				LADSPAPortDescriptor::Output   |
				LADSPAPortDescriptor::Audio
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);
}

MUSICDescriptor::~MUSICDescriptor()
{
}

LADSPAPluginInstance* MUSICDescriptor::create(unsigned long SampleRate)
{
	return new MUSICInstance(SampleRate);
}
