/* $Id: SCCDescriptor.cc,v 1.2 2003/09/17 19:08:14 andete Exp $

lemux - LADSPA instrument plugins based on openMSX devices

(c) 2003 Joost Yervante Damad <joost@lumatec.be>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "SCCDescriptor.hh"
#include "LADSPAPluginInstance.hh"
#include "LADSPAPortDescriptor.hh"
#include "LADSPAPluginDescriptor.hh"
#include "SCCInstance.hh"

#include <string>
#include <sstream>

SCCDescriptor::SCCDescriptor()
:
	LADSPAPluginDescriptor
		(
			2062,
			std::string("SCC"),
			std::string("SCC channel"),
			std::string("Joost Yervante Damad"),
			std::string("GPLv2")
		)
{
	LADSPAPortDescriptor *port;

	port = new LADSPAPortDescriptor
		(
			std::string("Freq (Hz)"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::SampleRate   |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default440,

			0,
			0.5
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Amplitude"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default1,

			0
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Preset"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove  |
				LADSPAPortDescriptor::Integer  |
				LADSPAPortDescriptor::Default0,

			0,
			SCC_PRESET_COUNT-1
		);
	addPort(port);



	port = new LADSPAPortDescriptor
		(
			std::string("Output"),
			
				LADSPAPortDescriptor::Output   |
				LADSPAPortDescriptor::Audio
		);
	addPort(port);

/* There used to be a control port for each byte, but that
   doesn't really work handy - Joost
	for (int i=0; i < 32; i++)
	{
		std::stringstream s;
		s << "Byte " << i;
		port = new LADSPAPortDescriptor
			(
				s.str(),
				
					LADSPAPortDescriptor::Input   |
					LADSPAPortDescriptor::Control ,
				
						LADSPAPortDescriptor::BoundedBelow |
					LADSPAPortDescriptor::BoundedAbove |
					LADSPAPortDescriptor::Integer      |
					LADSPAPortDescriptor::Default0     ,
	
				-127,
				127
			);
		addPort(port);
	}
*/

}

SCCDescriptor::~SCCDescriptor()
{
}

LADSPAPluginInstance* SCCDescriptor::create(unsigned long SampleRate)
{
	return new SCCInstance(SampleRate);
}
